from setuptools import setup

setup(
   name='yandex-events-processor',
   version='66.0.2',
   author='Yandex',
   author_email='security@yandex-team.ru',
   url='https://ya.ru',
   readme="README.md",
   long_description="""This is a security placeholder package.""",
   long_description_content_type='text/markdown',
   description='A package to prevent Dependency Confusion attacks against Yandex.',
   )
